@@ -6,7 +6,7 @@
 
 rgl.bringtotop <- function(stay = FALSE) {
 
-  if (!.Platform$OS=="window" && stay) warning("stay only works on Windows")
+  if ((.Platform$OS.type != "windows") && stay) warning("stay not implemented")
   ret <- .C( rgl_dev_bringtotop, success=FALSE, as.logical(stay) )
 
   if (! ret$success)
