@@ -19,7 +19,7 @@ public:
  
   enum Type { ALPHA = 1 , LUMINANCE, LUMINANCE_ALPHA, RGB, RGBA };
 
-  Texture(const char* filename
+  Texture(const char* in_filename
    , Type type
    , bool mipmap
    , unsigned int minfilter
@@ -30,6 +30,8 @@ public:
   void beginUse(RenderContext* renderContext);
   void endUse(RenderContext* renderContext);
   bool is_envmap() const { return envmap; }
+  void getParameters(Type *out_type, bool *out_mipmap, unsigned int *out_minfilter, 
+                     unsigned int *out_magfilter, bool *out_envmap, int bufsize, char *out_filename) ;
 private:
   void init(RenderContext* renderContext);
   Pixmap* pixmap;
@@ -39,6 +41,7 @@ private:
   GLenum  minfilter;
   GLenum  magfilter;
   bool    envmap;
+  char*   filename;
 };
 
 #endif // TEXTURE_HPP
