@@ -7,7 +7,7 @@
 #include "osxgui.hpp"
 // ---------------------------------------------------------------------------
 #include "R.h"
-#include <cassert>
+#include "assert.hpp"
 // ---------------------------------------------------------------------------
 namespace lib {
 // ---------------------------------------------------------------------------
